==> haskell-quickcheck-assertions-0.3.0-63-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-5tQhJJRMQi0Gl8VgVkwIpU
key: quickcheck-assertions-0.3.0-5tQhJJRMQi0Gl8VgVkwIpU
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 70c36c2e766dcf7839444e7319dc4478
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-5tQhJJRMQi0Gl8VgVkwIpU
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-mKBM7dhTVi7duC8FR6i8s
key: quickcheck-assertions-0.3.0-mKBM7dhTVi7duC8FR6i8s
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: c887d09973e7dea00ea264ab3bf9bbef
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-mKBM7dhTVi7duC8FR6i8s
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
